@@ -86,7 +86,20 @@ class RequestsMixin:
                     response = self.session.post(url, data=json.dumps(data), headers=JSON_HTTP_HEADERS)
                 else:
                     response = self.session.post(url)
-                break
+
+                if not response:
+                    raise ConnectionError("Connection was reset by a peer or the server rebooted.")
+                
+                if response.status_code == 200:
+                    return response
+                elif response.status_code == 403:
+                    raise AuthenticationError("Request could not be authenticated")
+                elif response.status_code == 404:
+                    raise ResourceNotFoundError("Requested resource not found")
+                elif response.status_code == 500:
+                    raise InternalServerError("Internal server error")
+
+                return response
 
             except requests.exceptions.ConnectionError:
                 if failure_count == 3:
@@ -94,18 +107,8 @@ class RequestsMixin:
 
                 failure_count += 1
                 continue
-
             except Exception:
-                raise ConnectionError("The remote address is bogus.")
-        
-        if response.status_code == 200:
-            return response
-        elif response.status_code == 403:
-            raise AuthenticationError("Request could not be authenticated")
-        elif response.status_code == 404:
-            raise ResourceNotFoundError("Requested resource not found")
-        elif response.status_code == 500:
-            raise InternalServerError("Internal server error")
+                raise ConnectionError("Remote address is bogus.")
 
 
     def _get_data(self, url):
@@ -121,7 +124,20 @@ class RequestsMixin:
         while failure_count < 3:
             try:
                 response = self.session.get(url)
-                break
+
+                if not response:
+                    raise ConnectionError("Connection was reset by a peer or the server rebooted.")
+
+                if response.status_code == 200:
+                    return response.json()
+                elif response.status_code == 403:
+                    raise AuthenticationError("Request could not be authenticated")
+                elif response.status_code == 404:
+                    raise ResourceNotFoundError("Requested resource not found")
+                elif response.status_code == 500:
+                    raise InternalServerError("Internal server error")
+
+                return response
 
             except requests.exceptions.ConnectionError as e:
                 if failure_count == 3:
@@ -130,14 +146,8 @@ class RequestsMixin:
                 failure_count += 1
                 continue
 
-        if response.status_code == 200:
-            return response.json()
-        elif response.status_code == 403:
-            raise AuthenticationError("Request could not be authenticated")
-        elif response.status_code == 404:
-            raise ResourceNotFoundError("Requested resource not found")
-        elif response.status_code == 500:
-            raise InternalServerError("Internal server error")
+            except Exception:
+                raise ConnectionError("Remote address is bogus.")
 
 
     def send_log_entry(self, text):
